@@ -2,9 +2,11 @@
 #'
 #' After loading a RasterStack of results, there are lots of NA values
 #' and plots of individual raster layers will display at the full extent of the
-#' study extent. To show an ideal extent, this function trims away 0 and
-#' NA values and checks to make sure it returns a reasonable extent for
-#' plotting. The returned Extent object can then be used for plotting.
+#' study extent. To show an ideal extent, this function trims away 0 and NA
+#' values and checks to make sure it returns a reasonable extent for plotting.
+#' The returned Extent object can then be used for plotting. To access a
+#' pre-calculated extent for the full annual cycle use
+#' [load_fac_map_parameters()].
 #'
 #' @param x Raster* object; either full RasterStack or subset.
 #'
@@ -23,7 +25,7 @@
 #' \donttest{
 #' # download and load example abundance data
 #' sp_path <- ebirdst_download("example_data")
-#' abd <- load_raster("abundance_umean", sp_path)
+#' abd <- load_raster("abundance", sp_path)
 #'
 #' # calculate full extent
 #' plot_extent <- calc_full_extent(abd)
@@ -64,8 +66,7 @@ calc_full_extent <- function(x) {
 }
 
 
-#' Calculates bins (breaks) based on standard deviations of Box-Cox
-#' power-transformed data for mapping
+#' Calculates bins (breaks) based for mapping
 #'
 #' Mapping species abundance across the full-annual cycle presents a challenge,
 #' in that patterns of concentration and dispersion in abundance change
@@ -75,14 +76,23 @@ calc_full_extent <- function(x) {
 #' that first selects an optimal power (the Box-Cox method) for normalizing
 #' the data, then power transforms the entire year of non-zero data, constructs
 #' bins with the power-transformed data using standard-deviations, and then
-#' un-transforms the bins.
+#' un-transforms the bins. To access a pre-calculated bins for the full annual
+#' cycle use [load_fac_map_parameters()].
 #'
 #' @param x RasterStack or RasterBrick; original eBird Status and Trends product
 #'   raster GeoTIFF with 52 bands, one for each week.
+#' @param method character; method to calculate bins: `"boxcox"` for bins based
+#'   on standard deviations of Box-Cox power-transformed data or `"quantile"`
+#'   for quantile bins.
 #'
 #' @return A list with two elements: `bins` is a vector containing the break
 #'   points of the bins and `power` is the optimal power used to transform data
-#'   when calculating bins.
+#'   when calculating bins. If `method = "quantile"` is used, `power` will be
+#'   missing.
+#'
+#' @details The Box-Cox method used in the online version of Status & Trends is
+#'   used as the default for calculating bins; however, an alternative method
+#'   using quantile-based bins can be used by setting `method = "quantile"`.
 #'
 #' @export
 #'
@@ -92,113 +102,124 @@ calc_full_extent <- function(x) {
 #' 19(1): 130-140, 2013.
 #'
 #' @examples
+#' \donttest{
 #' # download and load example abundance data
 #' sp_path <- ebirdst_download("example_data")
-#' abd <- load_raster("abundance_umean", sp_path)
-#' \dontshow{
-#' # crop to speed up cran tests
-#' e <-  raster::extent(abd)
-#' e[2] <- e[1] + (e[2] - e[1]) / 4
-#' e[4] <- e[3] + (e[4] - e[3]) / 4
-#' abd <- raster::crop(abd[[30]], e)
-#' }
+#' abd <- load_raster("abundance", sp_path)
 #'
 #' # calculate bins for a single week for this example
-#' year_bins <- calc_bins(abd)
-calc_bins <- function(x) {
+#' bins_boxcox <- calc_bins(abd)
+#' # for some scenarios quantile bins may work better
+#' bins_quantile <- calc_bins(abd, method = "quantile")
+#' }
+calc_bins <- function(x, method = c("boxcox", "quantile")) {
   stopifnot(inherits(x, "Raster"))
-
+  method <- match.arg(method)
   if (all(is.na(suppressWarnings(raster::maxValue(x)))) &
       all(is.na(suppressWarnings(raster::minValue(x))))) {
     stop("Input Raster* object must have non-NA values.")
   }
+  if (all(raster::maxValue(x) == 0)) {
+    stop("Raster must have at least 2 non-zero values to calculate bins")
+  }
 
   # get a vector of all the values in the stack
   zrv <- raster::getValues(x)
   vals_for_pt <- zrv[!is.na(zrv) & zrv > 0]
-
-  # box-cox transform
-  pt <- car::powerTransform(vals_for_pt)
-  this_power <- pt$lambda
-
-  lzwk <- vals_for_pt ^ this_power
-  rm(zrv)
-
-  # setup the binning structure
-  # calculate metrics
-  maxl <- max(lzwk, na.rm = TRUE)
-  minl <- min(lzwk, na.rm = TRUE)
-  mdl <- mean(lzwk, na.rm = TRUE)
-  sdl <- stats::sd(lzwk, na.rm = TRUE)
-  rm(lzwk)
-
-  # build a vector of bins
-  log_sd <- c(mdl - (3.00 * sdl), mdl - (2.50 * sdl), mdl - (2.00 * sdl),
-              mdl - (1.75 * sdl), mdl - (1.50 * sdl), mdl - (1.25 * sdl),
-              mdl - (1.00 * sdl), mdl - (0.75 * sdl), mdl - (0.50 * sdl),
-              mdl - (0.25 * sdl), mdl - (0.125 * sdl),
-              mdl,
-              mdl + (0.125 * sdl), mdl + (0.25 * sdl),
-              mdl + (0.50 * sdl), mdl + (0.75 * sdl), mdl + (1.00 * sdl),
-              mdl + (1.25 * sdl), mdl + (1.50 * sdl), mdl + (1.75 * sdl),
-              mdl + (2.00 * sdl), mdl + (2.50 * sdl), mdl + (3.00 * sdl))
-
-  # lots of checks for values outside of the upper and lower bounds
-
-  # remove +3 sd break if it is greater than max
-  if (maxl < mdl + (3.00 * sdl)) {
-    log_sd <- log_sd[1:length(log_sd) - 1]
+  if (length(vals_for_pt) <= 1) {
+    stop("Raster must have at least 2 non-zero values to calculate bins")
   }
 
-  # add max if the max is greater than +3 sd break
-  if (maxl > mdl + (3.00 * sdl) | maxl > log_sd[length(log_sd)]) {
-    log_sd <- append(log_sd, maxl)
-  }
+  if (method == "boxcox") {
+    # box-cox transform
+    pt <- car::powerTransform(vals_for_pt)
+    this_power <- pt$lambda
 
-  # remove the -3 sd break if it is less than the min
-  if (minl > mdl - (3.00 * sdl)) {
-    log_sd <- log_sd[2:length(log_sd)]
-  }
+    lzwk <- vals_for_pt^this_power
+    rm(zrv)
 
-  # add min if the min is less than -3 sd break
-  if (minl < mdl - (3.00 * sdl) | minl < log_sd[1]) {
-    log_sd <- append(log_sd, minl, after = 0)
-  }
+    # setup the binning structure
+    # calculate metrics
+    maxl <- max(lzwk, na.rm = TRUE)
+    minl <- min(lzwk, na.rm = TRUE)
+    mdl <- mean(lzwk, na.rm = TRUE)
+    sdl <- stats::sd(lzwk, na.rm = TRUE)
+    rm(lzwk)
 
-  if (log_sd[1] < 0) {
-    log_sd[1] <- 0.01 ^ this_power
-  }
+    # build a vector of bins
+    log_sd <- c(mdl - (3.00 * sdl), mdl - (2.50 * sdl), mdl - (2.00 * sdl),
+                mdl - (1.75 * sdl), mdl - (1.50 * sdl), mdl - (1.25 * sdl),
+                mdl - (1.00 * sdl), mdl - (0.75 * sdl), mdl - (0.50 * sdl),
+                mdl - (0.25 * sdl), mdl - (0.125 * sdl),
+                mdl,
+                mdl + (0.125 * sdl), mdl + (0.25 * sdl),
+                mdl + (0.50 * sdl), mdl + (0.75 * sdl), mdl + (1.00 * sdl),
+                mdl + (1.25 * sdl), mdl + (1.50 * sdl), mdl + (1.75 * sdl),
+                mdl + (2.00 * sdl), mdl + (2.50 * sdl), mdl + (3.00 * sdl))
 
-  if (log_sd[1] ^ (1 / this_power) < 0.01) {
-    log_sd[1] <- 0.01 ^ this_power
-  }
+    # lots of checks for values outside of the upper and lower bounds
 
-  # untransform
-  bins <- log_sd ^ (1 / this_power)
-  rm(log_sd)
+    # remove +3 sd break if it is greater than max
+    if (maxl < mdl + (3.00 * sdl)) {
+      log_sd <- log_sd[1:length(log_sd) - 1]
+    }
 
-  # if transform power was negative, flip bins
-  if (this_power < 0) {
-    bins <- rev(bins)
+    # add max if the max is greater than +3 sd break
+    if (maxl > mdl + (3.00 * sdl) | maxl > log_sd[length(log_sd)]) {
+      log_sd <- append(log_sd, maxl)
+    }
+
+    # remove the -3 sd break if it is less than the min
+    if (minl > mdl - (3.00 * sdl)) {
+      log_sd <- log_sd[2:length(log_sd)]
+    }
+
+    # add min if the min is less than -3 sd break
+    if (minl < mdl - (3.00 * sdl) | minl < log_sd[1]) {
+      log_sd <- append(log_sd, minl, after = 0)
+    }
+
+    if (log_sd[1] < 0) {
+      log_sd[1] <- 0.01 ^ this_power
+    }
+
+    if (log_sd[1] ^ (1 / this_power) < 0.01) {
+      log_sd[1] <- 0.01 ^ this_power
+    }
+
+    # untransform
+    bins <- log_sd ^ (1 / this_power)
+    rm(log_sd)
+
+    # if transform power was negative, flip bins
+    if (this_power < 0) {
+      bins <- rev(bins)
+    }
+  } else if (method == "quantile") {
+    bins <- stats::quantile(vals_for_pt,
+                            probs = seq(from = 0, to = 1, by = 0.05),
+                            na.rm = TRUE)
+    this_power <- NULL
+  } else {
+    stop(paste("unrecognized binning method:", method))
   }
 
   return(list(bins = sort(unname(bins)), power = unname(this_power)))
 }
 
 
-#' Map PI and PD centroid locations
+#' Map PI centroid locations
 #'
-#' Creates a map showing the stixel centroid locations for PIs and/or PDs, with
-#' an optional spatiotemporal subset using an [ebirdst_extent] object
+#' Creates a map showing the stixel centroid locations for predictor importance
+#' values, with an optional spatiotemporal subset using an [ebirdst_extent]
+#' object
 #'
 #' @param path character; full path to directory containing the eBird Status and
 #'   Trends products for a single species.
 #' @param ext [ebirdst_extent] object (optional); the spatiotemporal extent to
 #'   filter the data to.
-#' @param plot_pis logical; whether to show PI stixel centroid locations.
-#' @param plot_pds logical; whether to show PD stixel centroid locations.
 #'
-#' @return Plot showing locations of PIs and/or PDs.
+#' @return Plot showing locations of PI centroids.
 #'
 #' @export
 #'
@@ -211,13 +232,8 @@ calc_bins <- function(x) {
 #' e <- ebirdst_extent(bb_vec, t = c("05-01", "05-31"))
 #'
 #' map_centroids(path = sp_path, ext = e)
-map_centroids <- function(path, ext, plot_pis = TRUE, plot_pds = TRUE) {
+map_centroids <- function(path, ext) {
   stopifnot(is.character(path), length(path) == 1, dir.exists(path))
-  stopifnot(is.logical(plot_pis), length(plot_pis) == 1)
-  stopifnot(is.logical(plot_pds), length(plot_pds) == 1)
-  if (!plot_pds & !plot_pis) {
-    stop("Plotting of both PIs and PDs set to FALSE. Nothing to plot!")
-  }
   if (missing(ext)) {
     stop("A spatiotemporal extent must be provided.")
   } else {
@@ -231,26 +247,13 @@ map_centroids <- function(path, ext, plot_pis = TRUE, plot_pds = TRUE) {
               pi_a = "#d95f0e", pi_s = "#feb24c")
 
   # convert data to spatial, find bounding box
-  # pds
-  if (isTRUE(plot_pds)) {
-    pds <- load_pds(path = path)
-    pds <- dplyr::distinct(pds[, c("lon", "lat", "date")])
-    pds <- sf::st_as_sf(pds, coords = c("lon", "lat"), crs = 4326)
-    pds <- sf::st_transform(pds, crs = mollweide)
-  } else {
-    pds <- NULL
-  }
   # pis
-  if (isTRUE(plot_pis)) {
-    pis <- load_pis(path = path)
-    pis <- dplyr::distinct(pis[, c("lon", "lat", "date")])
-    pis <- sf::st_as_sf(pis, coords = c("lon", "lat"), crs = 4326)
-    pis <- sf::st_transform(pis, crs = mollweide)
-  } else {
-    pis <- NULL
-  }
+  pis <- load_pis(path = path)
+  pis <- dplyr::distinct(pis[, c("lon", "lat", "date")])
+  pis <- sf::st_as_sf(pis, coords = c("lon", "lat"), crs = 4326)
+  pis <- sf::st_transform(pis, crs = mollweide)
   # bbox
-  bb <- sf::st_as_sfc(sf::st_bbox(rbind(pis, pds)))
+  bb <- sf::st_as_sfc(sf::st_bbox(pis))
 
   # initialize graphical parameters
   p <- graphics::par(mfrow = c(1, 1), mar = c(0, 0, 0, 0), bg = "white")
@@ -264,58 +267,29 @@ map_centroids <- function(path, ext, plot_pis = TRUE, plot_pds = TRUE) {
   xwidth <- usr[2] - usr[1]
   yheight <- usr[4] - usr[3]
 
-  # plotting pds
-  if (isTRUE(plot_pds)) {
-    # first plot all possible pds
-    graphics::plot(sf::st_geometry(pds), col = pal$pd_a, cex = 0.4, pch = 16,
-                   add = TRUE)
-    graphics::text(x = usr[1] + 0.05 * xwidth,
-                   y = usr[3] + 0.2 * yheight,
-                   adj = 0,
-                   paste("Available PDs: ", nrow(pds), sep = ""),
-                   cex = 1,
-                   col = pal$pd_a)
-
-    # plot pds within extent
-    if (!missing(ext)) {
-      pds_sub <- ebirdst_subset(pds, ext)
-      graphics::plot(sf::st_geometry(pds_sub),
-                     col = pal$pd_s, cex = 0.4, pch = 16,
-                     add = TRUE)
-      graphics::text(x = usr[1] + 0.05 * xwidth,
-                     y = usr[3] + 0.16 * yheight,
-                     adj = 0,
-                     paste("Selected PDs: ", nrow(pds_sub), sep = ""),
-                     cex = 1,
-                     col = pal$pd_s)
-    }
-  }
-
   # plotting pis
-  if (isTRUE(plot_pis)) {
-    # first plot all possible pis
-    graphics::plot(sf::st_geometry(pis), col = pal$pi_a, cex = 0.4, pch = 16,
+  # first plot all possible pis
+  graphics::plot(sf::st_geometry(pis), col = pal$pi_a, cex = 0.4, pch = 16,
+                 add = TRUE)
+  graphics::text(x = usr[1] + 0.05 * xwidth,
+                 y = usr[3] + 0.12 * yheight,
+                 adj = 0,
+                 paste("Available PIs: ", nrow(pis), sep = ""),
+                 cex = 1,
+                 col = pal$pi_a)
+
+  # plot pis within extent
+  if (!missing(ext)) {
+    pis_sub <- ebirdst_subset(pis, ext)
+    graphics::plot(sf::st_geometry(pis_sub),
+                   col = pal$pi_s, cex = 0.4, pch = 16,
                    add = TRUE)
     graphics::text(x = usr[1] + 0.05 * xwidth,
-                   y = usr[3] + 0.12 * yheight,
+                   y = usr[3] + 0.08 * yheight,
                    adj = 0,
-                   paste("Available PIs: ", nrow(pis), sep = ""),
+                   paste("Selected PIs: ", nrow(pis_sub), sep = ""),
                    cex = 1,
-                   col = pal$pi_a)
-
-    # plot pis within extent
-    if (!missing(ext)) {
-      pis_sub <- ebirdst_subset(pis, ext)
-      graphics::plot(sf::st_geometry(pis_sub),
-                     col = pal$pi_s, cex = 0.4, pch = 16,
-                     add = TRUE)
-      graphics::text(x = usr[1] + 0.05 * xwidth,
-                     y = usr[3] + 0.08 * yheight,
-                     adj = 0,
-                     paste("Selected PIs: ", nrow(pis_sub), sep = ""),
-                     cex = 1,
-                     col = pal$pi_s)
-    }
+                   col = pal$pi_s)
   }
 
   # plot reference data
@@ -329,40 +303,20 @@ map_centroids <- function(path, ext, plot_pis = TRUE, plot_pds = TRUE) {
   xwidth <- usr[2] - usr[1]
   yheight <- usr[4] - usr[3]
 
-  # pds
-  if (isTRUE(plot_pds)) {
-    graphics::text(x = usr[1] + 0.05 * xwidth,
-                   y = usr[3] + 0.2 * yheight,
-                   adj = 0,
-                   paste("Available PDs: ", nrow(pds), sep = ""),
-                   cex = 1,
-                   col = pal$pd_a)
-    if (!missing(ext)) {
-      graphics::text(x = usr[1] + 0.05 * xwidth,
-                     y = usr[3] + 0.16 * yheight,
-                     adj = 0,
-                     paste("Selected PDs: ", nrow(pds_sub), sep = ""),
-                     cex = 1,
-                     col = pal$pd_s)
-    }
-  }
-
   # pis
-  if (isTRUE(plot_pis)) {
+  graphics::text(x = usr[1] + 0.05 * xwidth,
+                 y = usr[3] + 0.12 * yheight,
+                 adj = 0,
+                 paste("Available PIs: ", nrow(pis), sep = ""),
+                 cex = 1,
+                 col = pal$pi_a)
+  if (!missing(ext)) {
     graphics::text(x = usr[1] + 0.05 * xwidth,
-                   y = usr[3] + 0.12 * yheight,
+                   y = usr[3] + 0.08 * yheight,
                    adj = 0,
-                   paste("Available PIs: ", nrow(pis), sep = ""),
+                   paste("Selected PIs: ", nrow(pis_sub), sep = ""),
                    cex = 1,
-                   col = pal$pi_a)
-    if (!missing(ext)) {
-      graphics::text(x = usr[1] + 0.05 * xwidth,
-                     y = usr[3] + 0.08 * yheight,
-                     adj = 0,
-                     paste("Selected PIs: ", nrow(pis_sub), sep = ""),
-                     cex = 1,
-                     col = pal$pi_s)
-    }
+                   col = pal$pi_s)
   }
 
   graphics::par(p)
@@ -372,9 +326,9 @@ map_centroids <- function(path, ext, plot_pis = TRUE, plot_pds = TRUE) {
 
 #' Calculate and map effective extent of selected centroids
 #'
-#' The selection of stixel centroids for analysis of PIs and/or PDs yields an
+#' The selection of stixel centroids for analysis of predictor importances (PIs) yields an
 #' effective footprint, or extent, showing the effective location of where the
-#' information going into the analysis with PIs and/or PDs is based. While a
+#' information going into the analysis with PIs is based. While a
 #' bounding box or polygon may be used to select a set of centroids, due to the
 #' models being fit within large rectangular areas, the information from a set
 #' of centroids often comes from the core of the selected area. This function
@@ -387,8 +341,6 @@ map_centroids <- function(path, ext, plot_pis = TRUE, plot_pds = TRUE) {
 #'   Trends products for a single species.
 #' @param ext [ebirdst_extent] object (optional); the spatiotemporal
 #'   extent to filter the data to.
-#' @param pi_pd character; whether to use predictor importance (`"pi"`) or
-#'   partial dependence (`"pd"`) for stixel centroids.
 #' @param plot logical; whether to plot the results or just return a raster
 #'   without plotting.
 #'
@@ -400,21 +352,19 @@ map_centroids <- function(path, ext, plot_pis = TRUE, plot_pds = TRUE) {
 #' @export
 #'
 #' @examples
+#' \donttest{
 #' # download and load example data
 #' sp_path <- ebirdst_download("example_data", tifs_only = FALSE)
 #'
 #' # define a spatioremporal extent
 #' bb_vec <- c(xmin = -86, xmax = -84, ymin = 41.5, ymax = 43.5)
 #' e <- ebirdst_extent(bb_vec, t = c("05-01", "05-31"))
-#' \donttest{
 #' # calculate effective extent map
-#' eff <- calc_effective_extent(path = sp_path, ext = e, pi_pd = "pi")
+#' eff <- calc_effective_extent(path = sp_path, ext = e)
 #' }
-calc_effective_extent <- function(path, ext, pi_pd = c("pi", "pd"),
-                                  plot = TRUE) {
+calc_effective_extent <- function(path, ext, plot = TRUE) {
   stopifnot(is.character(path), length(path) == 1, dir.exists(path))
   stopifnot(inherits(ext, "ebirdst_extent"))
-  pi_pd <- match.arg(pi_pd)
   stopifnot(is.logical(plot), length(plot) == 1)
   if (all(c(0, 1) == round(ext$t, 2))) {
     warning(paste("Without temporal limits in ext, this function will take",
@@ -423,11 +373,7 @@ calc_effective_extent <- function(path, ext, pi_pd = c("pi", "pd"),
 
   # load data
   r_tmplt <- load_raster(product = "template", path = path)
-  if (pi_pd == "pi") {
-    pipd <- load_pis(path = path)
-  } else {
-    pipd <- load_pds(path = path)
-  }
+  pipd <- load_pis(path = path)
 
   # subset
   pipd <- dplyr::distinct(pipd[, c("lon", "lat", "date", "stixel_width",
